import _extends from '@babel/runtime/helpers/extends';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import React__default from 'react';
import classnames from 'classnames';
import { isEmpty, isNil, omit } from 'ramda';
import Button from './Button.js';
import Tooltip from './Tooltip.js';
import Typography from './Typography.js';
import '@babel/runtime/helpers/defineProperty';
import 'react-router-dom';
import './Spinner.js';
import '@babel/runtime/helpers/slicedToArray';
import '@tippyjs/react';
import 'tippy.js';

var renderImage = function renderImage(image) {
  return typeof image === "string" ? /*#__PURE__*/React__default.createElement("img", {
    "data-cy": "no-data-image",
    src: image
  }) : image;
};

var _excluded = ["image", "title", "description", "helpText", "className", "primaryButtonProps", "secondaryButtonProps", "buttonSeparatorText", "showTooltipWhenButtonDisabled"];
var NoData = function NoData(_ref) {
  var _ref$image = _ref.image,
    image = _ref$image === void 0 ? null : _ref$image,
    _ref$title = _ref.title,
    title = _ref$title === void 0 ? "" : _ref$title,
    _ref$description = _ref.description,
    description = _ref$description === void 0 ? "" : _ref$description,
    _ref$helpText = _ref.helpText,
    helpText = _ref$helpText === void 0 ? null : _ref$helpText,
    _ref$className = _ref.className,
    className = _ref$className === void 0 ? "" : _ref$className,
    _ref$primaryButtonPro = _ref.primaryButtonProps,
    primaryButtonProps = _ref$primaryButtonPro === void 0 ? {} : _ref$primaryButtonPro,
    _ref$secondaryButtonP = _ref.secondaryButtonProps,
    secondaryButtonProps = _ref$secondaryButtonP === void 0 ? {} : _ref$secondaryButtonP,
    _ref$buttonSeparatorT = _ref.buttonSeparatorText,
    buttonSeparatorText = _ref$buttonSeparatorT === void 0 ? "" : _ref$buttonSeparatorT,
    _ref$showTooltipWhenB = _ref.showTooltipWhenButtonDisabled,
    showTooltipWhenButtonDisabled = _ref$showTooltipWhenB === void 0 ? false : _ref$showTooltipWhenB,
    otherProps = _objectWithoutProperties(_ref, _excluded);
  var hasPrimaryButtonProps = !isEmpty(primaryButtonProps);
  var hasSecondaryButtonProps = !isEmpty(secondaryButtonProps);
  var hasButtonSeparatorText = !isEmpty(buttonSeparatorText);
  var showButtonSeparator = hasButtonSeparatorText && hasPrimaryButtonProps && hasSecondaryButtonProps;
  return /*#__PURE__*/React__default.createElement("div", _extends({
    className: classnames("neeto-ui-no-data", [className]),
    "data-cy": "no-data-container"
  }, otherProps), image ? /*#__PURE__*/React__default.createElement("div", {
    className: "neeto-ui-no-data__image"
  }, renderImage(image)) : null, title && /*#__PURE__*/React__default.createElement(Typography, {
    className: "neeto-ui-text-center",
    "data-cy": "no-data-title",
    lineHeight: "none",
    style: "h3"
  }, title), description && /*#__PURE__*/React__default.createElement(Typography, {
    className: "neeto-ui-text-center neeto-ui-no-data__description",
    "data-cy": "no-data-description",
    lineHeight: "normal",
    style: "body2"
  }, description), helpText && /*#__PURE__*/React__default.createElement(Typography, {
    className: "neeto-ui-text-center neeto-ui-no-data__help-text",
    "data-cy": "no-data-help-text",
    lineHeight: "normal",
    style: "body2"
  }, helpText), (hasPrimaryButtonProps || hasSecondaryButtonProps) && /*#__PURE__*/React__default.createElement("div", {
    className: "neeto-ui-no-data__action-block"
  }, hasPrimaryButtonProps && /*#__PURE__*/React__default.createElement(Tooltip, _extends({}, primaryButtonProps === null || primaryButtonProps === void 0 ? void 0 : primaryButtonProps.tooltipProps, {
    disabled: isNil(primaryButtonProps === null || primaryButtonProps === void 0 ? void 0 : primaryButtonProps.tooltipProps) || !showTooltipWhenButtonDisabled && (primaryButtonProps === null || primaryButtonProps === void 0 ? void 0 : primaryButtonProps.disabled)
  }), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement(Button, _extends({
    "data-cy": "no-data-primary-button",
    "data-testid": "no-data-primary-button"
  }, omit(["tooltipProps"], primaryButtonProps))))), showButtonSeparator && /*#__PURE__*/React__default.createElement(Typography, {
    lineHeight: "normal",
    style: "body2"
  }, buttonSeparatorText), hasSecondaryButtonProps && /*#__PURE__*/React__default.createElement(Tooltip, _extends({}, secondaryButtonProps === null || secondaryButtonProps === void 0 ? void 0 : secondaryButtonProps.tooltipProps, {
    disabled: isNil(secondaryButtonProps === null || secondaryButtonProps === void 0 ? void 0 : secondaryButtonProps.tooltipProps) || !showTooltipWhenButtonDisabled && (secondaryButtonProps === null || secondaryButtonProps === void 0 ? void 0 : secondaryButtonProps.disabled)
  }), /*#__PURE__*/React__default.createElement("div", null, /*#__PURE__*/React__default.createElement(Button, _extends({
    "data-cy": "no-data-secondary-button",
    "data-testid": "no-data-secondary-button",
    style: "secondary"
  }, omit(["tooltipProps"], secondaryButtonProps)))))));
};

export { NoData as default };
//# sourceMappingURL=NoData.js.map
