'use strict';

var _ConfigProvider = require('antd/lib/config-provider');
var _Table = require('antd/lib/table');
var _extends = require('@babel/runtime/helpers/extends');
var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var _slicedToArray = require('@babel/runtime/helpers/slicedToArray');
var _objectWithoutProperties = require('@babel/runtime/helpers/objectWithoutProperties');
var React = require('react');
var classnames = require('classnames');
var neetoCist = require('@bigbinary/neeto-cist');
var neetoIcons = require('@bigbinary/neeto-icons');
var ramda = require('ramda');
var ReactDragListView = require('react-drag-listview');
var reactI18next = require('react-i18next');
var reactRouterDom = require('react-router-dom');
var constants = require('./constants.js');
require('@bigbinary/neeto-hotkeys');
require('./overlayManager.js');
var index = require('./index-Ci1VcKxO.js');
var useQueryParams = require('./useQueryParams-l5fJJYCR.js');
var Button = require('./Button.js');
var Callout = require('./Callout.js');
var Typography = require('./Typography.js');
var useRestoreScrollPosition = require('./useRestoreScrollPosition-CBHtwLFj.js');
var _toConsumableArray = require('@babel/runtime/helpers/toConsumableArray');
var Popover = require('./Popover.js');
var reactResizable = require('react-resizable');
var Spinner = require('./Spinner.js');
require('antd/locale/de_DE');
require('antd/locale/en_US');
require('antd/locale/es_ES');
require('antd/locale/fr_FR');
require('antd/locale/nl_NL');
require('antd/locale/pl_PL');
require('antd/locale/pt_PT');
require('@babel/runtime/helpers/classCallCheck');
require('@babel/runtime/helpers/createClass');
require('qs');
require('./en-CPeHe9Ab.js');
require('dayjs');
require('dayjs/plugin/localeData');
require('dayjs/plugin/utc');
require('dayjs/plugin/weekday');
require('dayjs/plugin/weekOfYear');
require('./Tooltip.js');
require('@tippyjs/react');
require('tippy.js');
require('./Dropdown.js');
require('zustand');

var useTimeout = function useTimeout(callback, delay) {
  var savedCallback = React.useRef(callback);
  React.useEffect(function () {
    savedCallback.current = callback;
  }, [callback]);
  React.useEffect(function () {
    var id = setTimeout(function () {
      return savedCallback.current();
    }, delay);
    return function () {
      return clearTimeout(id);
    };
  }, [delay]);
};

// eslint-disable-next-line @bigbinary/neeto/no-dumb-components-with-use-translation
var AllRowsSelectedCallout = function AllRowsSelectedCallout(_ref) {
  var calloutProps = _ref.calloutProps,
    onClearSelection = _ref.onClearSelection,
    allRowsSelectedMessage = _ref.allRowsSelectedMessage,
    clearSelectionButtonLabel = _ref.clearSelectionButtonLabel;
  var _useTranslation = reactI18next.useTranslation(),
    t = _useTranslation.t,
    i18n = _useTranslation.i18n;
  return /*#__PURE__*/React.createElement(Callout, _extends({
    className: "my-2"
  }, calloutProps, {
    "data-testid": "clear-selections-callout"
  }), /*#__PURE__*/React.createElement("div", {
    className: "neeto-ui-flex neeto-ui-gap-3"
  }, /*#__PURE__*/React.createElement(Typography, {
    style: "body2"
  }, allRowsSelectedMessage || index.getLocale(i18n, t, "neetoui.table.allRowsSelected")), /*#__PURE__*/React.createElement(Button, {
    "data-testid": "clear-selections-button",
    style: "link",
    label: clearSelectionButtonLabel || index.getLocale(i18n, t, "neetoui.table.clearSelection"),
    onClick: onClearSelection
  })));
};

var SelectAllRowsCallout = function SelectAllRowsCallout(_ref) {
  var calloutProps = _ref.calloutProps,
    onBulkSelectAllRows = _ref.onBulkSelectAllRows,
    selectAllRowButtonLabel = _ref.selectAllRowButtonLabel,
    selectAllRowMessage = _ref.selectAllRowMessage;
  return /*#__PURE__*/React.createElement(Callout, _extends({
    className: "my-2"
  }, calloutProps, {
    "data-testid": "select-all-rows-callout"
  }), /*#__PURE__*/React.createElement("div", {
    className: "neeto-ui-flex neeto-ui-gap-3"
  }, /*#__PURE__*/React.createElement(Typography, {
    style: "body2"
  }, selectAllRowMessage), /*#__PURE__*/React.createElement(Button, {
    "data-testid": "select-all-rows-button",
    label: selectAllRowButtonLabel,
    style: "link",
    onClick: onBulkSelectAllRows
  })));
};

var useLocalStorage = function useLocalStorage(key, defaultValue) {
  var _useState = React.useState(function () {
      return index.getFromLocalStorage(key, defaultValue);
    }),
    _useState2 = _slicedToArray(_useState, 2),
    storedValue = _useState2[0],
    setStoredValue = _useState2[1];
  var setValue = function setValue(value) {
    return setStoredValue(function (prevStoredValue) {
      var newValue = typeof value === "function" ? value(prevStoredValue) : value;
      if (ramda.isNil(newValue)) {
        index.removeFromLocalStorage(key);
      } else {
        index.setToLocalStorage(key, newValue);
      }
      return newValue;
    });
  };
  return [storedValue, setValue];
};

var useReorderColumns = function useReorderColumns(_ref) {
  var isEnabled = _ref.isEnabled,
    columns = _ref.columns,
    setColumns = _ref.setColumns,
    onColumnUpdate = _ref.onColumnUpdate,
    rowSelection = _ref.rowSelection;
  if (!isEnabled) return {
    dragProps: {},
    columns: columns
  };
  var isColumnFixed = function isColumnFixed(column) {
    return !!column.fixed;
  };
  var dragProps = {
    onDragEnd: function onDragEnd(fromIndex, toIndex) {
      var from = fromIndex;
      var to = toIndex;
      if (rowSelection) {
        from = fromIndex - 1;
        to = toIndex - 1;
      }
      if (!columns[from] || !columns[to]) return;
      if (isColumnFixed(columns[from]) || isColumnFixed(columns[to])) return;
      var newColumns = ramda.move(from, to, columns);
      setColumns(newColumns);
      onColumnUpdate(newColumns);
    },
    nodeSelector: "th:not(.ant-table-cell-fix-left):not(.ant-table-cell-scrollbar)",
    handleSelector: ".drag-handler",
    ignoreSelector: ".react-resizable-handle"
  };
  return {
    dragProps: dragProps,
    columns: columns
  };
};

var SortIcon = function SortIcon(_ref) {
  var sortOrder = _ref.sortOrder;
  if (sortOrder === useRestoreScrollPosition.TABLE_SORT_ORDERS.asc || sortOrder === useRestoreScrollPosition.URL_SORT_ORDERS.ascend) {
    return /*#__PURE__*/React.createElement(neetoIcons.UpArrow, {
      size: 14
    });
  }
  if (sortOrder === useRestoreScrollPosition.TABLE_SORT_ORDERS.desc || sortOrder === useRestoreScrollPosition.URL_SORT_ORDERS.descend) {
    return /*#__PURE__*/React.createElement(neetoIcons.DownArrow, {
      size: 14
    });
  }
  return null;
};

var _excluded$5 = ["title", "description"];
var TitleWithInfoIcon = function TitleWithInfoIcon(_ref) {
  var title = _ref.title,
    description = _ref.description,
    rest = _objectWithoutProperties(_ref, _excluded$5);
  var popoverRef = React.useRef();
  return /*#__PURE__*/React.createElement("span", {
    className: "relative pr-5"
  }, typeof title === "function" ? title(rest) : title, description && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
    className: "neeto-ui-table__column-title-info-icon",
    ref: popoverRef
  }, /*#__PURE__*/React.createElement(neetoIcons.InfoRound, {
    color: "currentColor",
    size: 14
  })), /*#__PURE__*/React.createElement(Popover, {
    appendTo: function appendTo() {
      return document.body;
    },
    reference: popoverRef
  }, /*#__PURE__*/React.createElement(Typography, {
    lineHeight: "normal",
    style: "body2"
  }, description))));
};

var _excluded$4 = ["children", "isSortable", "isAddEnabled", "sortedInfo", "onSort", "isHidable", "isDeletable", "isFixedColumn", "isColumnFreezeEnabled", "onColumnHide", "onAddColumn", "onColumnDelete", "onColumnFreeze", "onMoreActionClick", "column", "moreActions"];
var CellContent = function CellContent(_ref) {
  var children = _ref.children,
    isSortable = _ref.isSortable,
    isAddEnabled = _ref.isAddEnabled,
    sortedInfo = _ref.sortedInfo,
    onSort = _ref.onSort,
    _ref$isHidable = _ref.isHidable,
    isHidable = _ref$isHidable === void 0 ? true : _ref$isHidable,
    _ref$isDeletable = _ref.isDeletable,
    isDeletable = _ref$isDeletable === void 0 ? false : _ref$isDeletable,
    isFixedColumn = _ref.isFixedColumn,
    isColumnFreezeEnabled = _ref.isColumnFreezeEnabled,
    onColumnHide = _ref.onColumnHide,
    onAddColumn = _ref.onAddColumn,
    onColumnDelete = _ref.onColumnDelete,
    onColumnFreeze = _ref.onColumnFreeze,
    onMoreActionClick = _ref.onMoreActionClick,
    column = _ref.column,
    _ref$moreActions = _ref.moreActions,
    moreActions = _ref$moreActions === void 0 ? [] : _ref$moreActions,
    headerProps = _objectWithoutProperties(_ref, _excluded$4);
  var isColumnHidable = isHidable && neetoCist.isPresent(onColumnHide);
  var isColumnDeletable = isDeletable && neetoCist.isPresent(onColumnDelete);
  var hasMoreActions = !ramda.isEmpty(moreActions) && neetoCist.isPresent(onMoreActionClick);
  var hasMoreMenu = isSortable || isColumnHidable || isAddEnabled || hasMoreActions || neetoCist.isPresent(column) && isColumnFreezeEnabled;
  return /*#__PURE__*/React.createElement("th", _extends({}, headerProps, {
    title: "",
    onClick: isSortable ? neetoCist.noop : headerProps.onClick
  }), /*#__PURE__*/React.createElement("div", {
    className: "neeto-ui-flex neeto-ui-items-center neeto-ui-justify-between",
    "data-cy": "".concat(index.hyphenize(headerProps.title), "-header-title")
  }, /*#__PURE__*/React.createElement("div", {
    className: "neeto-ui-min-w-0 neeto-ui-flex-grow neeto-ui-truncate neeto-ui-table__column-title-content"
  }, children), hasMoreMenu && /*#__PURE__*/React.createElement(useRestoreScrollPosition.HeaderCellMenu, {
    column: column,
    hasMoreActions: hasMoreActions,
    isAddEnabled: isAddEnabled,
    isColumnDeletable: isColumnDeletable,
    isColumnFreezeEnabled: isColumnFreezeEnabled,
    isFixedColumn: isFixedColumn,
    isSortable: isSortable,
    moreActions: moreActions,
    onAddColumn: onAddColumn,
    onColumnDelete: onColumnDelete,
    onColumnFreeze: onColumnFreeze,
    onColumnHide: onColumnHide,
    onMoreActionClick: onMoreActionClick,
    onSort: onSort,
    sortedInfo: sortedInfo,
    isHidable: isColumnHidable
  })));
};

var _excluded$3 = ["onResize", "width", "onResizeStop", "className"];
var HeaderCell = function HeaderCell(props) {
  var onResize = props.onResize,
    width = props.width,
    onResizeStop = props.onResizeStop,
    className = props.className,
    restProps = _objectWithoutProperties(props, _excluded$3);
  if (!width) {
    return /*#__PURE__*/React.createElement(CellContent, _extends({}, restProps, {
      className: classnames(className, "drag-handler")
    }));
  }
  return /*#__PURE__*/React.createElement(reactResizable.Resizable, {
    onResize: onResize,
    onResizeStop: onResizeStop,
    width: width,
    draggableOpts: {
      enableUserSelectHack: false
    },
    height: 0,
    handle: /*#__PURE__*/React.createElement("span", {
      className: "react-resizable-handle",
      onClick: function onClick(e) {
        return e.stopPropagation();
      }
    }),
    onResizeStart: function onResizeStart(e) {
      e.preventDefault();
    }
  }, /*#__PURE__*/React.createElement(CellContent, _extends({}, restProps, {
    className: classnames(className, "drag-handler")
  })));
};

var _excluded$2 = ["onResize", "width", "onResizeStop"];
var ResizableHeaderCell = function ResizableHeaderCell(props) {
  var onResize = props.onResize,
    width = props.width,
    onResizeStop = props.onResizeStop,
    restProps = _objectWithoutProperties(props, _excluded$2);
  if (!width) {
    return /*#__PURE__*/React.createElement(CellContent, restProps);
  }
  return /*#__PURE__*/React.createElement(reactResizable.Resizable, {
    onResize: onResize,
    onResizeStop: onResizeStop,
    width: width,
    draggableOpts: {
      enableUserSelectHack: false
    },
    height: 0,
    handle: /*#__PURE__*/React.createElement("span", {
      className: "react-resizable-handle",
      onClick: function onClick(e) {
        return e.stopPropagation();
      }
    }),
    onResizeStart: function onResizeStart(e) {
      e.preventDefault();
    }
  }, /*#__PURE__*/React.createElement(CellContent, restProps));
};

var _excluded$1 = ["className"];
var ReorderableHeaderCell = function ReorderableHeaderCell(_ref) {
  var className = _ref.className,
    props = _objectWithoutProperties(_ref, _excluded$1);
  return /*#__PURE__*/React.createElement(CellContent, _extends({}, props, {
    className: classnames(className, "drag-handler")
  }));
};

var convertLocationPathnameToId = function convertLocationPathnameToId() {
  var pathname = decodeURIComponent(window.location.pathname).replace(/^\//, "");
  var hash = 0;
  for (var i = 0; i < pathname.length; i++) {
    var _char = pathname.charCodeAt(i);
    hash = (hash << 5) - hash + _char;
    hash = hash & hash; // Convert to 32-bit integer
  }

  return Math.abs(hash).toString(16).toUpperCase();
};
var getHeaderCell = function getHeaderCell(_ref) {
  var enableColumnResize = _ref.enableColumnResize,
    enableColumnReorder = _ref.enableColumnReorder;
  if (enableColumnReorder && enableColumnResize) return {
    cell: HeaderCell
  };
  if (enableColumnResize) return {
    cell: ResizableHeaderCell
  };
  if (enableColumnReorder) return {
    cell: ReorderableHeaderCell
  };
  return {
    cell: CellContent
  };
};
var isIncludedIn = function isIncludedIn(array1, array2) {
  return ramda.all(ramda.includes(ramda.__, array1), array2);
};
var getSelectAllRowsCalloutHeight = function getSelectAllRowsCalloutHeight() {
  return window.innerWidth < 768 ? useRestoreScrollPosition.SELECT_ALL_ROWS_CALLOUT_MOBILE_HEIGHT : useRestoreScrollPosition.SELECT_ALL_ROWS_CALLOUT_DESKTOP_HEIGHT;
};
var sortFrozenColumns = function sortFrozenColumns(columnData) {
  var originalIndices = new Map(columnData.map(function (col, index) {
    return [col.dataIndex, index];
  }));
  return function (a, b) {
    var aFixed = neetoCist.isPresent(a.fixed);
    var bFixed = neetoCist.isPresent(b.fixed);
    var aIndex = originalIndices.get(a.dataIndex);
    var bIndex = originalIndices.get(b.dataIndex);
    if (aFixed !== bFixed) return aFixed ? -1 : 1;
    return aIndex - bIndex;
  };
};
var getFixedColumns = function getFixedColumns(columnData) {
  return ramda.pipe(ramda.filter(function (_ref2) {
    var fixed = _ref2.fixed;
    return neetoCist.isPresent(fixed);
  }), ramda.pluck("dataIndex"))(columnData);
};
var getColumnSortOrder = function getColumnSortOrder(col, sortedInfo) {
  return ramda.equals(sortedInfo.field, col.dataIndex) || ramda.equals(sortedInfo.field, col.key) ? sortedInfo.order : null;
};
var getColumFixedValue = function getColumFixedValue(col, frozenColumns) {
  return frozenColumns.indexOf(col.dataIndex) !== -1 ? useRestoreScrollPosition.COLUMN_FIXED_VALUES.LEFT : null;
};
var getFrozenColumnsLocalStorageKey = function getFrozenColumnsLocalStorageKey(localStorageKeyPrefix) {
  var prefix = neetoCist.isPresent(localStorageKeyPrefix) ? localStorageKeyPrefix : convertLocationPathnameToId();
  return "NEETOUI-".concat(prefix, "-FIXED_COLUMNS");
};
var getSortInfoFromQueryParams = function getSortInfoFromQueryParams(queryParams) {
  var sortedInfo = {};
  if (neetoCist.isPresent(queryParams.sort_by) && neetoCist.isPresent(queryParams.order_by) && neetoCist.isPresent(useRestoreScrollPosition.TABLE_SORT_ORDERS[queryParams.order_by])) {
    sortedInfo.field = queryParams.sort_by.includes("+") ? queryParams.sort_by.split("+").map(neetoCist.snakeToCamelCase) : neetoCist.snakeToCamelCase(queryParams.sort_by);
    sortedInfo.order = useRestoreScrollPosition.TABLE_SORT_ORDERS[queryParams.order_by];
  }
  return sortedInfo;
};
var getSortField = function getSortField(field) {
  if (Array.isArray(field)) {
    return field.map(neetoCist.camelToSnakeCase).join("+");
  }
  return neetoCist.camelToSnakeCase(field);
};

function ownKeys$2(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread$2(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$2(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$2(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var useResizableColumns = function useResizableColumns(_ref) {
  var columns = _ref.columns,
    columnData = _ref.columnData,
    frozenColumns = _ref.frozenColumns,
    setColumns = _ref.setColumns,
    isEnabled = _ref.isEnabled,
    isAddEnabled = _ref.isAddEnabled,
    isColumnFreezeEnabled = _ref.isColumnFreezeEnabled,
    onColumnAdd = _ref.onColumnAdd,
    onColumnUpdate = _ref.onColumnUpdate,
    onColumnDelete = _ref.onColumnDelete,
    handleSort = _ref.handleSort,
    sortedInfo = _ref.sortedInfo,
    onColumnHide = _ref.onColumnHide,
    onColumnFreeze = _ref.onColumnFreeze,
    onMoreActionClick = _ref.onMoreActionClick,
    tableOnChangeProps = _ref.tableOnChangeProps;
  var handleResize = function handleResize(index) {
    return function (_, _ref2) {
      var size = _ref2.size;
      var nextColumns = _toConsumableArray(columns);
      nextColumns[index] = _objectSpread$2(_objectSpread$2({}, nextColumns[index]), {}, {
        width: size.width
      });
      setColumns(nextColumns);
    };
  };
  var computedColumnsData = React.useMemo(function () {
    return columns.map(function (col, index) {
      var fixed = getColumFixedValue(col, frozenColumns);
      var modifiedColumn = _objectSpread$2(_objectSpread$2({}, col), {}, {
        onHeaderCell: function onHeaderCell(column) {
          return {
            width: column.width,
            onResize: isEnabled ? handleResize(index) : neetoCist.noop,
            onResizeStop: function onResizeStop() {
              return isEnabled ? onColumnUpdate(columns) : neetoCist.noop;
            },
            isSortable: neetoCist.isPresent(col.sorter),
            onSort: handleSort,
            sortedInfo: sortedInfo,
            onColumnHide: onColumnHide,
            onColumnFreeze: onColumnFreeze,
            onMoreActionClick: onMoreActionClick,
            isColumnFreezeEnabled: isColumnFreezeEnabled,
            isAddEnabled: isAddEnabled && !fixed,
            onAddColumn: function onAddColumn(positionOffset) {
              return onColumnAdd(index + positionOffset);
            },
            isFixedColumn: !!fixed,
            onColumnDelete: onColumnDelete,
            isHidable: col.isHidable,
            isDeletable: col.isDeletable,
            moreActions: col.moreActions,
            column: col,
            "data-text-align": column.align
          };
        },
        sortIcon: SortIcon,
        sortOrder: getColumnSortOrder(col, sortedInfo),
        fixed: fixed,
        title: col.description ? function (props) {
          return /*#__PURE__*/React.createElement(TitleWithInfoIcon, _extends({}, props, {
            description: col.description,
            title: col.title
          }));
        } : col.title
      });
      if (!ramda.has("ellipsis", col)) modifiedColumn.ellipsis = true;
      return modifiedColumn;
    }).sort(sortFrozenColumns(columnData));
  }, [columns, sortedInfo, tableOnChangeProps, onColumnFreeze, frozenColumns, columnData]);
  return {
    columns: computedColumnsData
  };
};

function ownKeys$1(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread$1(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$1(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$1(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var useColumns = function useColumns(_ref) {
  var columns = _ref.columns,
    columnData = _ref.columnData,
    setColumns = _ref.setColumns,
    isResizeEnabled = _ref.isResizeEnabled,
    isReorderEnabled = _ref.isReorderEnabled,
    isAddEnabled = _ref.isAddEnabled,
    isColumnFreezeEnabled = _ref.isColumnFreezeEnabled,
    onColumnAdd = _ref.onColumnAdd,
    onColumnUpdate = _ref.onColumnUpdate,
    onColumnDelete = _ref.onColumnDelete,
    rowSelection = _ref.rowSelection,
    sortedInfo = _ref.sortedInfo,
    setSortedInfo = _ref.setSortedInfo,
    onColumnHide = _ref.onColumnHide,
    onMoreActionClick = _ref.onMoreActionClick,
    onTableChange = _ref.onTableChange,
    tableOnChangeProps = _ref.tableOnChangeProps,
    handleTableSortChange = _ref.handleTableSortChange,
    isDefaultPageChangeHandler = _ref.isDefaultPageChangeHandler,
    localStorageKeyPrefix = _ref.localStorageKeyPrefix;
  var didSetInitialFrozenColumnsRef = React.useRef(false);
  var _useLocalStorage = useLocalStorage(getFrozenColumnsLocalStorageKey(localStorageKeyPrefix), getFixedColumns(columnData)),
    _useLocalStorage2 = _slicedToArray(_useLocalStorage, 2),
    frozenColumns = _useLocalStorage2[0],
    setFrozenColumns = _useLocalStorage2[1];
  var onColumnFreeze = React.useCallback(function (isFixedColumn, _ref2) {
    var dataIndex = _ref2.dataIndex;
    var updatedColumns = isFixedColumn ? ramda.without([dataIndex], frozenColumns) : ramda.append(dataIndex, frozenColumns);
    setFrozenColumns(updatedColumns);
  }, [frozenColumns, setFrozenColumns]);
  React.useEffect(function () {
    if (ramda.isEmpty(columnData) || didSetInitialFrozenColumnsRef.current) return;
    var fixedCols = getFixedColumns(columnData);
    setFrozenColumns(ramda.union(fixedCols));
    didSetInitialFrozenColumnsRef.current = true;
  }, [columnData, setFrozenColumns]);
  var _useReorderColumns = useReorderColumns({
      isEnabled: isReorderEnabled,
      columns: columns,
      setColumns: setColumns,
      onColumnUpdate: onColumnUpdate,
      rowSelection: rowSelection
    }),
    dragProps = _useReorderColumns.dragProps;
  var handleSort = function handleSort(sorter) {
    var _tableOnChangeProps$c, _tableOnChangeProps$c2, _tableOnChangeProps$c3;
    var newSortedInfo = _objectSpread$1({}, sorter);
    if (ramda.equals(ramda.props(["field", "order"], newSortedInfo), ramda.props(["field", "order"], sortedInfo))) {
      newSortedInfo = {
        field: null,
        order: null,
        column: null,
        columnKey: null
      };
    }
    setSortedInfo(newSortedInfo);
    onTableChange === null || onTableChange === void 0 || onTableChange(((_tableOnChangeProps$c = tableOnChangeProps.current) === null || _tableOnChangeProps$c === void 0 ? void 0 : _tableOnChangeProps$c.pagination) || {}, ((_tableOnChangeProps$c2 = tableOnChangeProps.current) === null || _tableOnChangeProps$c2 === void 0 ? void 0 : _tableOnChangeProps$c2.filters) || {}, _objectSpread$1({}, newSortedInfo));
    isDefaultPageChangeHandler && handleTableSortChange(((_tableOnChangeProps$c3 = tableOnChangeProps.current) === null || _tableOnChangeProps$c3 === void 0 ? void 0 : _tableOnChangeProps$c3.pagination) || {}, newSortedInfo);
  };
  var _useResizableColumns = useResizableColumns({
      columns: columns,
      columnData: columnData,
      frozenColumns: frozenColumns,
      setColumns: setColumns,
      isEnabled: isResizeEnabled,
      isAddEnabled: isAddEnabled,
      isColumnFreezeEnabled: isColumnFreezeEnabled,
      onColumnAdd: onColumnAdd,
      onColumnUpdate: onColumnUpdate,
      onColumnDelete: onColumnDelete,
      handleSort: handleSort,
      sortedInfo: sortedInfo,
      onColumnHide: onColumnHide,
      onMoreActionClick: onMoreActionClick,
      tableOnChangeProps: tableOnChangeProps,
      onColumnFreeze: onColumnFreeze
    }),
    computedColumnsData = _useResizableColumns.columns;
  return {
    dragProps: dragProps,
    columns: computedColumnsData
  };
};

var useTableSort = function useTableSort() {
  var queryParams = useQueryParams.useQueryParams();
  var _useState = React.useState(function () {
      return getSortInfoFromQueryParams(queryParams);
    }),
    _useState2 = _slicedToArray(_useState, 2),
    sortedInfo = _useState2[0],
    setSortedInfo = _useState2[1];
  React.useEffect(function () {
    setSortedInfo(getSortInfoFromQueryParams(queryParams));
  }, [queryParams === null || queryParams === void 0 ? void 0 : queryParams.sort_by, queryParams === null || queryParams === void 0 ? void 0 : queryParams.order_by]);
  var history = reactRouterDom.useHistory();
  var handleTableChange = function handleTableChange(pagination, sorter) {
    var params = {
      sort_by: sorter.order ? getSortField(sorter.field) : undefined,
      order_by: useRestoreScrollPosition.URL_SORT_ORDERS[sorter.order],
      page: pagination.current
    };
    var pathname = window.location.pathname;
    history.push(index.buildUrl(pathname, ramda.mergeLeft(params, queryParams)));
  };
  return {
    handleTableChange: handleTableChange,
    sortedInfo: sortedInfo,
    setSortedInfo: setSortedInfo
  };
};

var _excluded = ["allowRowClick", "enableColumnResize", "enableColumnReorder", "enableColumnFreeze", "enableAddColumn", "className", "columnData", "currentPageNumber", "defaultPageSize", "handlePageChange", "loading", "onRowClick", "onRowSelect", "rowData", "totalCount", "selectedRowKeys", "fixedHeight", "paginationProps", "rowKey", "scroll", "rowSelection", "shouldDynamicallyRenderRowSize", "bordered", "onColumnUpdate", "components", "onColumnHide", "onColumnAdd", "onColumnDelete", "onChange", "onMoreActionClick", "bulkSelectAllRowsProps", "localStorageKeyPrefix"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var TABLE_PAGINATION_HEIGHT = 64;
var TABLE_DEFAULT_HEADER_HEIGHT = 40;
var TABLE_ROW_HEIGHT = 52;
var Table = function Table(_ref) {
  var _ref$allowRowClick = _ref.allowRowClick,
    allowRowClick = _ref$allowRowClick === void 0 ? true : _ref$allowRowClick,
    _ref$enableColumnResi = _ref.enableColumnResize,
    enableColumnResize = _ref$enableColumnResi === void 0 ? true : _ref$enableColumnResi,
    _ref$enableColumnReor = _ref.enableColumnReorder,
    enableColumnReorder = _ref$enableColumnReor === void 0 ? false : _ref$enableColumnReor,
    _ref$enableColumnFree = _ref.enableColumnFreeze,
    enableColumnFreeze = _ref$enableColumnFree === void 0 ? true : _ref$enableColumnFree,
    _ref$enableAddColumn = _ref.enableAddColumn,
    enableAddColumn = _ref$enableAddColumn === void 0 ? false : _ref$enableAddColumn,
    _ref$className = _ref.className,
    className = _ref$className === void 0 ? "" : _ref$className,
    _ref$columnData = _ref.columnData,
    columnData = _ref$columnData === void 0 ? [] : _ref$columnData,
    _ref$currentPageNumbe = _ref.currentPageNumber,
    currentPageNumber = _ref$currentPageNumbe === void 0 ? 1 : _ref$currentPageNumbe,
    _ref$defaultPageSize = _ref.defaultPageSize,
    defaultPageSize = _ref$defaultPageSize === void 0 ? 30 : _ref$defaultPageSize,
    _ref$handlePageChange = _ref.handlePageChange,
    handlePageChange = _ref$handlePageChange === void 0 ? index.noop : _ref$handlePageChange,
    _ref$loading = _ref.loading,
    loading = _ref$loading === void 0 ? false : _ref$loading,
    onRowClick = _ref.onRowClick,
    onRowSelect = _ref.onRowSelect,
    _ref$rowData = _ref.rowData,
    rowData = _ref$rowData === void 0 ? [] : _ref$rowData,
    _ref$totalCount = _ref.totalCount,
    totalCount = _ref$totalCount === void 0 ? 0 : _ref$totalCount,
    _ref$selectedRowKeys = _ref.selectedRowKeys,
    initialSelectedRowKeys = _ref$selectedRowKeys === void 0 ? [] : _ref$selectedRowKeys,
    _ref$fixedHeight = _ref.fixedHeight,
    fixedHeight = _ref$fixedHeight === void 0 ? false : _ref$fixedHeight,
    _ref$paginationProps = _ref.paginationProps,
    paginationProps = _ref$paginationProps === void 0 ? {} : _ref$paginationProps,
    _ref$rowKey = _ref.rowKey,
    rowKey = _ref$rowKey === void 0 ? "id" : _ref$rowKey,
    scroll = _ref.scroll,
    rowSelection = _ref.rowSelection,
    _ref$shouldDynamicall = _ref.shouldDynamicallyRenderRowSize,
    shouldDynamicallyRenderRowSize = _ref$shouldDynamicall === void 0 ? false : _ref$shouldDynamicall,
    _ref$bordered = _ref.bordered,
    bordered = _ref$bordered === void 0 ? true : _ref$bordered,
    _ref$onColumnUpdate = _ref.onColumnUpdate,
    onColumnUpdate = _ref$onColumnUpdate === void 0 ? index.noop : _ref$onColumnUpdate,
    _ref$components = _ref.components,
    components = _ref$components === void 0 ? {} : _ref$components,
    onColumnHide = _ref.onColumnHide,
    _ref$onColumnAdd = _ref.onColumnAdd,
    onColumnAdd = _ref$onColumnAdd === void 0 ? index.noop : _ref$onColumnAdd,
    onColumnDelete = _ref.onColumnDelete,
    onChange = _ref.onChange,
    onMoreActionClick = _ref.onMoreActionClick,
    bulkSelectAllRowsProps = _ref.bulkSelectAllRowsProps,
    localStorageKeyPrefix = _ref.localStorageKeyPrefix,
    otherProps = _objectWithoutProperties(_ref, _excluded);
  var _useTranslation = reactI18next.useTranslation(),
    i18n = _useTranslation.i18n;
  var _useState = React.useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    containerHeight = _useState2[0],
    setContainerHeight = _useState2[1];
  var _useState3 = React.useState(TABLE_DEFAULT_HEADER_HEIGHT),
    _useState4 = _slicedToArray(_useState3, 2),
    headerHeight = _useState4[0],
    setHeaderHeight = _useState4[1];
  var _useState5 = React.useState(columnData),
    _useState6 = _slicedToArray(_useState5, 2),
    columns = _useState6[0],
    setColumns = _useState6[1];
  var _useState7 = React.useState(false),
    _useState8 = _slicedToArray(_useState7, 2),
    bulkSelectedAllRows = _useState8[0],
    setBulkSelectedAllRows = _useState8[1];
  var _useTableSort = useTableSort(),
    handleTableSortChange = _useTableSort.handleTableChange,
    sortedInfo = _useTableSort.sortedInfo,
    setSortedInfo = _useTableSort.setSortedInfo;
  var _ref2 = bulkSelectAllRowsProps !== null && bulkSelectAllRowsProps !== void 0 ? bulkSelectAllRowsProps : {},
    handleSetBulkSelectedAllRows = _ref2.setBulkSelectedAllRows;
  var isDefaultPageChangeHandler = handlePageChange === index.noop;
  var history = reactRouterDom.useHistory();
  var headerRef = React.useRef();
  var tableOnChangeProps = React.useRef({});
  var resizeObserver = React.useRef(new ResizeObserver(function (_ref3) {
    var _ref4 = _slicedToArray(_ref3, 1),
      entry = _ref4[0];
    return setContainerHeight(entry.contentRect.height);
  }));
  var scrollRef = React.useRef(null);
  var tableRef = React.useCallback(function (table) {
    scrollRef.current = table;
    if (!fixedHeight) return;
    var observer = resizeObserver.current;
    if (table !== null) {
      var _table$parentNode;
      var targetNode = enableColumnReorder ? table === null || table === void 0 || (_table$parentNode = table.parentNode) === null || _table$parentNode === void 0 ? void 0 : _table$parentNode.parentNode : table === null || table === void 0 ? void 0 : table.parentNode;
      observer.observe(targetNode);
    } else if (observer) {
      observer.disconnect();
    }
  }, [resizeObserver.current, fixedHeight, enableColumnReorder]);
  var _useRestoreScrollPosi = useRestoreScrollPosition.useRestoreScrollPosition({
      tableRef: tableRef,
      scrollRef: scrollRef,
      loading: loading
    }),
    handleScroll = _useRestoreScrollPosi.handleScroll;
  useTimeout(function () {
    var headerHeight = headerRef.current ? headerRef.current.offsetHeight : TABLE_DEFAULT_HEADER_HEIGHT;
    setHeaderHeight(headerHeight);
  }, 10);
  var _useColumns = useColumns({
      isReorderEnabled: enableColumnReorder,
      isResizeEnabled: enableColumnResize,
      isAddEnabled: enableAddColumn,
      isColumnFreezeEnabled: enableColumnFreeze,
      onTableChange: onChange,
      columns: columns,
      columnData: columnData,
      setColumns: setColumns,
      onColumnUpdate: onColumnUpdate,
      rowSelection: rowSelection,
      sortedInfo: sortedInfo,
      setSortedInfo: setSortedInfo,
      onColumnHide: onColumnHide,
      onMoreActionClick: onMoreActionClick,
      onColumnAdd: onColumnAdd,
      onColumnDelete: onColumnDelete,
      tableOnChangeProps: tableOnChangeProps,
      handleTableSortChange: handleTableSortChange,
      isDefaultPageChangeHandler: isDefaultPageChangeHandler,
      localStorageKeyPrefix: localStorageKeyPrefix
    }),
    dragProps = _useColumns.dragProps,
    curatedColumnsData = _useColumns.columns;
  var queryParams = useQueryParams.useQueryParams();
  var setSortFromURL = function setSortFromURL(columnData) {
    var _queryParams$sort_by;
    return neetoCist.modifyBy({
      dataIndex: neetoCist.snakeToCamelCase((_queryParams$sort_by = queryParams.sort_by) !== null && _queryParams$sort_by !== void 0 ? _queryParams$sort_by : "")
    }, ramda.assoc("sortOrder", useRestoreScrollPosition.TABLE_SORT_ORDERS[queryParams.order_by]), columnData);
  };
  var sortedColumns = isDefaultPageChangeHandler ? setSortFromURL(curatedColumnsData) : curatedColumnsData;
  var locale = {
    emptyText: /*#__PURE__*/React.createElement(Typography, {
      style: "body2"
    }, "No Data")
  };
  var selectedRowKeys = bulkSelectedAllRows ? ramda.pluck(rowKey, rowData) : initialSelectedRowKeys;
  var showBulkSelectionCallout = React.useMemo(function () {
    return isIncludedIn(selectedRowKeys, ramda.pluck(rowKey, rowData)) && selectedRowKeys.length !== totalCount && !bulkSelectedAllRows;
  }, [selectedRowKeys, rowKey, rowData, totalCount, bulkSelectedAllRows]);
  var shouldShowSelectAllRowsCallout = bulkSelectAllRowsProps && showBulkSelectionCallout;
  var shouldShowAllRowsSelectedCallout = bulkSelectAllRowsProps && bulkSelectedAllRows;
  var handleRowChange = function handleRowChange(selectedRowKeys, selectedRows) {
    var tableWrapper = document.querySelector('[data-testid="table-wrapper"]');
    if (selectedRowKeys.length !== defaultPageSize) {
      setBulkSelectedAllRows(false);
      handleSetBulkSelectedAllRows === null || handleSetBulkSelectedAllRows === void 0 || handleSetBulkSelectedAllRows(false);
      tableWrapper === null || tableWrapper === void 0 || tableWrapper.classList.remove("neeto-ui-overflow-hidden");
    } else {
      tableWrapper === null || tableWrapper === void 0 || tableWrapper.classList.add("neeto-ui-overflow-hidden");
    }
    onRowSelect === null || onRowSelect === void 0 || onRowSelect(selectedRowKeys, selectedRows);
  };
  var rowSelectionProps = rowSelection ? _objectSpread(_objectSpread({
    type: "checkbox",
    preserveSelectedRowKeys: true
  }, rowSelection), {}, {
    onChange: handleRowChange,
    selectedRowKeys: selectedRowKeys
  }) : false;

  // eslint-disable-next-line @bigbinary/neeto/no-excess-function-arguments
  var handleTableChange = function handleTableChange(pagination, filters, sorter, extras) {
    setSortedInfo(sorter);
    isDefaultPageChangeHandler && handleTableSortChange(pagination, sorter);
    onChange === null || onChange === void 0 || onChange(pagination, filters, sorter, extras);
    tableOnChangeProps.current = {
      pagination: pagination,
      filters: filters
    };
  };
  var componentOverrides = _objectSpread(_objectSpread({}, components), {}, {
    header: getHeaderCell({
      enableColumnResize: enableColumnResize,
      enableColumnReorder: enableColumnReorder
    })
  });
  var calculateRowsPerPage = function calculateRowsPerPage() {
    var viewportHeight = window.innerHeight;
    var rowsPerPage = Math.floor((viewportHeight - TABLE_PAGINATION_HEIGHT) / TABLE_ROW_HEIGHT * 3);
    return Math.ceil(rowsPerPage / 10) * 10;
  };
  var pageSize = shouldDynamicallyRenderRowSize ? calculateRowsPerPage() : paginationProps.pageSize || defaultPageSize;
  var calculateTableContainerHeight = function calculateTableContainerHeight() {
    var isPaginationVisible = otherProps.pagination !== false && rowData.length > pageSize;
    var selectAllRowsCalloutHeight = 0;
    if (shouldShowSelectAllRowsCallout || shouldShowAllRowsSelectedCallout) {
      selectAllRowsCalloutHeight = getSelectAllRowsCalloutHeight();
    }
    return containerHeight - headerHeight - (isPaginationVisible ? TABLE_PAGINATION_HEIGHT : 0) - selectAllRowsCalloutHeight;
  };
  var calculatePageSizeOptions = function calculatePageSizeOptions() {
    return neetoCist.dynamicArray(5, function (index) {
      return (index + 1) * pageSize;
    });
  };
  var itemRender = function itemRender(_, type, originalElement) {
    var commonProps = {
      size: "small",
      style: "text"
    };
    if (type === "prev") return /*#__PURE__*/React.createElement(Button, _extends({
      icon: neetoIcons.Left
    }, commonProps));
    if (type === "next") return /*#__PURE__*/React.createElement(Button, _extends({
      icon: neetoIcons.Right
    }, commonProps));
    if (type === "jump-prev" || type === "jump-next") {
      return /*#__PURE__*/React.createElement(Button, _extends({
        icon: neetoIcons.MenuHorizontal
      }, commonProps));
    }
    return originalElement;
  };
  React.useEffect(function () {
    if (neetoCist.isNotEmpty(initialSelectedRowKeys)) return;
    setBulkSelectedAllRows(false);
    handleSetBulkSelectedAllRows === null || handleSetBulkSelectedAllRows === void 0 || handleSetBulkSelectedAllRows(false);
  }, [handleSetBulkSelectedAllRows, initialSelectedRowKeys]);
  React.useEffect(function () {
    var shouldNavigateToLastPage = ramda.isEmpty(rowData) && !loading && currentPageNumber !== 1;
    if (!shouldNavigateToLastPage) return;
    var lastPage = Math.ceil(totalCount / pageSize);
    var page = Math.max(1, lastPage);
    var pathname = window.location.pathname;
    isDefaultPageChangeHandler ? history.push(index.buildUrl(pathname, ramda.mergeLeft({
      page: page
    }, queryParams))) : handlePageChange(page, pageSize);
  }, [rowData]);
  React.useEffect(function () {
    return setColumns(columnData);
  }, [columnData]);
  var neetoUIFontBold = parseInt(getComputedStyle(document.documentElement).getPropertyValue("--neeto-ui-font-bold"), 10);
  var renderTable = function renderTable() {
    return /*#__PURE__*/React.createElement(_ConfigProvider, {
      locale: constants.ANTD_LOCALE[i18n.language || "en"],
      theme: {
        token: _objectSpread({}, index.ANT_DESIGN_GLOBAL_TOKEN_OVERRIDES),
        components: {
          Pagination: {
            itemActiveBg: "rgb(var(--neeto-ui-primary-500))",
            itemActiveBgDisabled: "rgb(var(--neeto-ui-gray-50))",
            itemActiveColorDisabled: "rgb(var(--neeto-ui-gray-300))",
            itemBg: "rgb(var(--neeto-ui-white))",
            itemInputBg: "rgb(var(--neeto-ui-white))",
            itemLinkBg: "rgb(var(--neeto-ui-white))",
            // Global overrides
            colorBgContainer: "rgb(var(--neeto-ui-primary-500))",
            colorPrimary: "rgb(var(--neeto-ui-white))",
            colorPrimaryHover: "rgb(var(--neeto-ui-white))",
            colorBgTextHover: "rgb(var(--neeto-ui-gray-200))",
            borderRadius: 6
          },
          Table: {
            headerBorderRadius: 0,
            bodySortBg: "rgb(var(--neeto-ui-gray-50))",
            borderColor: "rgb(var(--neeto-ui-gray-200))",
            expandIconBg: "rgb(var(--neeto-ui-white))",
            filterDropdownBg: "rgb(var(--neeto-ui-white))",
            filterDropdownMenuBg: "rgb(var(--neeto-ui-white))",
            fixedHeaderSortActiveBg: "rgb(var(--neeto-ui-gray-200))",
            footerBg: "rgb(var(--neeto-ui-gray-100))",
            footerColor: "rgb(var(--neeto-ui-black))",
            headerBg: "rgb(var(--neeto-ui-gray-100))",
            headerColor: "rgb(var(--neeto-ui-black))",
            headerFilterHoverBg: "rgb(var(--neeto-ui-gray-100))",
            headerSortActiveBg: "rgb(var(--neeto-ui-gray-200))",
            headerSortHoverBg: "rgb(var(--neeto-ui-gray-200))",
            headerSplitColor: "rgb(var(--neeto-ui-gray-100))",
            rowExpandedBg: "rgb(var(--neeto-ui-gray-100))",
            rowHoverBg: "rgb(var(--neeto-ui-gray-50))",
            rowSelectedBg: "rgb(var(--neeto-ui-accent-50))",
            rowSelectedHoverBg: "rgb(var(--neeto-ui-accent-50))",
            stickyScrollBarBg: "rgb(var(--neeto-ui-gray-300))",
            cellPaddingBlock: 11,
            // Global overrides
            colorPrimary: "rgb(var(--neeto-ui-primary-500))",
            fontSize: 14,
            fontWeightStrong: neetoUIFontBold,
            paddingContentVerticalLG: 11
          }
        }
      }
    }, shouldShowSelectAllRowsCallout && /*#__PURE__*/React.createElement(SelectAllRowsCallout, _extends({}, bulkSelectAllRowsProps, {
      onBulkSelectAllRows: function onBulkSelectAllRows() {
        setBulkSelectedAllRows(true);
        handleSetBulkSelectedAllRows === null || handleSetBulkSelectedAllRows === void 0 || handleSetBulkSelectedAllRows(true);
      }
    })), shouldShowAllRowsSelectedCallout && /*#__PURE__*/React.createElement(AllRowsSelectedCallout, _extends({}, bulkSelectAllRowsProps, {
      onClearSelection: function onClearSelection() {
        setBulkSelectedAllRows(false);
        handleSetBulkSelectedAllRows === null || handleSetBulkSelectedAllRows === void 0 || handleSetBulkSelectedAllRows(false);
        handleRowChange([], []);
      }
    })), /*#__PURE__*/React.createElement(_Table, _extends({
      bordered: bordered,
      locale: locale,
      rowKey: rowKey,
      columns: sortedColumns,
      components: componentOverrides,
      dataSource: rowData,
      loading: {
        spinning: loading,
        indicator: /*#__PURE__*/React.createElement(Spinner, null)
      },
      ref: tableRef,
      rowSelection: rowSelectionProps,
      showSorterTooltip: false,
      pagination: _objectSpread(_objectSpread({
        hideOnSinglePage: true
      }, paginationProps), {}, {
        showSizeChanger: false,
        total: totalCount !== null && totalCount !== void 0 ? totalCount : 0,
        current: currentPageNumber,
        defaultPageSize: pageSize,
        pageSizeOptions: calculatePageSizeOptions(),
        onChange: handlePageChange,
        itemRender: itemRender
      }),
      rowClassName: classnames("neeto-ui-table--row", {
        "neeto-ui-table--row_hover": allowRowClick
      }, [className]),
      scroll: _objectSpread({
        x: "max-content",
        y: calculateTableContainerHeight()
      }, scroll),
      onChange: handleTableChange,
      onScroll: handleScroll,
      onHeaderRow: function onHeaderRow() {
        return {
          ref: headerRef,
          className: classnames("neeto-ui-table__header", {
            "neeto-ui-table-reorderable": enableColumnReorder
          }),
          id: "neeto-ui-table__header"
        };
      },
      onRow: function onRow(record, rowIndex) {
        return {
          onClick: function onClick(event) {
            return allowRowClick && onRowClick && onRowClick(event, record, rowIndex);
          }
        };
      }
    }, otherProps)));
  };
  return enableColumnReorder ? /*#__PURE__*/React.createElement(ReactDragListView.DragColumn, dragProps, renderTable()) : renderTable();
};

module.exports = Table;
//# sourceMappingURL=Table.js.map
